# mandayejs - saml reverse proxy
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
from __future__ import absolute_import

from django import forms

from mandayejs.applications import get_app_settings



class FormFactory(forms.Form):

    def __init__(self, *args, **kwargs):
        super(FormFactory, self).__init__(*args, **kwargs)
        app_settings = get_app_settings()

        fields = getattr(app_settings, 'SITE_LOCATORS', [])
        if fields:
            for field in fields:
                if field['kind'] == 'string':
                    self.fields[field['name']] = forms.CharField(
                        label=field['label'],
                        max_length=32,
                        help_text=field.get('help', '')
                    )
                elif field['kind'] == 'password':
                    self.fields[field['name']] = forms.CharField(
                        label=field['label'],
                        widget=forms.PasswordInput(),
                        help_text=field.get('help', '')
                    )
                else:
                    self.fields[field['name']] = forms.DateField(
                        label=field['label'],
                        help_text=field.get('help', '')
                    )
